pub trait WindowSize: Unsigned {
type TableSize: ArraySize;
}Expand description
Allowed wNAF window size: we use this to precompute the window point sizes, because it’s currently not possible to write bounds for them.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".